@@ -58,8 +58,10 @@ input string '123456789':
   CRC-16-USB: B4C8
   CRC-CCITT: 29B1
   CRC-HDLC: 906E
+  CRC-XModem: 31C3
   CRC-24: 21CF02
   CRC-32: CBF43926
+  CRC-32-GCC: 0376E6E7
   CRC-32C: E3069283
   CRC-64: 46A5A9388A5BEFFE
   CRC-256: 79B96BDC0C519B239BE759EC0688C86FD25A3F4DF1E7F054AD1F923D0739DAC8
@@ -124,17 +126,19 @@ import sys
 # <http://docutils.sourceforge.net/docs/ref/rst/restructuredtext.html>
 __docformat__ = 'restructuredtext en'
 
-__version__ = '1.1'
+__version__ = '1.3'
 
 if sys.version_info[0] > 2:
     long = int
 
+algorithms = {}
+
 class CrcAlgorithm(object):
     """
     Represents the parameters of a CRC algorithm.
     """
 
-    def __init__(self, width, polynomial, name, seed=0, lsb_first=False, lsb_first_data=None, xor_mask=0):
+    def __init__(self, width, polynomial, name=None, seed=0, lsb_first=False, lsb_first_data=None, xor_mask=0):
         """
         :param width:
 
@@ -208,7 +212,7 @@ class CrcAlgorithm(object):
                 if lsb_first:
                     polymask = reflect(polynomial, width)
                 else:
-                    polymask = polynomail
+                    polymask = polynomial
                 polynomial = (width,)
                 for i in range(width - 1, -1, -1):
                     if (polymask >> i) & 1:
@@ -219,7 +223,6 @@ class CrcAlgorithm(object):
                 polynomial.reverse()
                 polynomial = tuple(polynomial)
             else:
-                import pdb; pdb.set_trace()
                 raise TypeError('polynomial must be either an int, list, or tuple')
 
             if polynomial[:1] != (width,):
@@ -233,6 +236,9 @@ class CrcAlgorithm(object):
         self.lsb_first_data = lsb_first_data
         self.xor_mask = xor_mask
 
+        if name is not None:
+            algorithms[name] = self
+
     def __repr__(self):
         result = "<{0}.{1} '{2}' {3} >".format(self.__class__.__module__, self.__class__.__name__, self.name, id(self))
         return result
@@ -454,9 +460,9 @@ CRC5_USB = CrcAlgorithm(
     name='CRC-5-USB',
     width=5,
     polynomial=(5, 2, 0),
-    seed=0x1F,
+    seed=0x1f,
     lsb_first=True,
-    xor_mask=0x1F
+    xor_mask=0x1f
 )
 
 #: Used in ATM HEC and SMBus.
@@ -493,16 +499,16 @@ CRC16_USB = CrcAlgorithm(
     name='CRC-16-USB',
     width=16,
     polynomial=(16, 15, 2, 0),
-    seed=0xFFFF,
+    seed=0xffff,
     lsb_first=True,
-    xor_mask=0xFFFF
+    xor_mask=0xffff
 )
 
 CRC_CCITT = CrcAlgorithm(
     name='CRC-CCITT',
     width=16,
     polynomial=(16, 12, 5, 0),
-    seed=0xFFFF,
+    seed=0xffff,
     lsb_first=False,
     xor_mask=0x0000
 )
@@ -512,9 +518,9 @@ CRC_HDLC = CrcAlgorithm(
     name='CRC-HDLC',
     width=16,
     polynomial=(16, 12, 5, 0),
-    seed=0xFFFF,
+    seed=0xffff,
     lsb_first=True,
-    xor_mask=0xFFFF
+    xor_mask=0xffff
 )
 
 CRC_XMODEM = CrcAlgorithm(
@@ -531,7 +537,7 @@ CRC24 = CrcAlgorithm(
     name='CRC-24',
     width=24,
     polynomial=(24, 23, 18, 17, 14, 11, 10, 7, 6, 5, 4, 3, 1, 0),
-    seed=0xB704CE,
+    seed=0xb704ce,
     lsb_first=False,
     xor_mask=0
 )
@@ -541,9 +547,9 @@ CRC32 = CrcAlgorithm(
     name='CRC-32',
     width=32,
     polynomial=(32, 26, 23, 22, 16, 12, 11, 10, 8, 7, 5, 4, 2, 1, 0),
-    seed=0xFFFFFFFF,
+    seed=0xffffffff,
     lsb_first=True,
-    xor_mask=0xFFFFFFFF
+    xor_mask=0xffffffff
 )
 
 #: Used in iSCSI (RFC-3385); usually credited to Guy Castagnoli.
@@ -551,9 +557,19 @@ CRC32C = CrcAlgorithm(
     name='CRC-32C',
     width=32,
     polynomial=(32, 28, 27, 26, 25, 23, 22, 20, 19, 18, 14, 13, 11, 10, 9, 8, 6, 0),
-    seed=0xFFFFFFFF,
+    seed=0xffffffff,
     lsb_first=True,
-    xor_mask=0xFFFFFFFF
+    xor_mask=0xffffffff
+)
+
+#: Same CRC algorithm as used in GCC
+CRC32_GCC = CrcAlgorithm(
+    name='CRC-32-GCC',
+    width=32,
+    polynomial=(32, 26, 23, 22, 16, 12, 11, 10, 8, 7, 5, 4, 2, 1, 0),
+    seed=0xffffffff,
+    lsb_first=False,
+    xor_mask=0
 )
 
 #: ISO 3309
@@ -573,8 +589,8 @@ CRC64 = CrcAlgorithm(
 CRC256 = CrcAlgorithm(
     name='CRC-256',
     width=256,
-    polynomial=0x82E2443E6320383A20B8A2A0A1EA91A3CCA99A30C5205038349C82AAA3A8FD27,
-    seed=0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF,
+    polynomial=0x82e2443e6320383a20b8a2a0a1ea91a3cca99a30c5205038349c82aaa3a8fd27,
+    seed=0xffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff,
     lsb_first=True,
     xor_mask=0
 )
